@@ -1,4 +1,4 @@
-# (c) 2002-2003 Mathieu Roy <yeupou@gnu.org>
+# (c) 2002-2005 Mathieu Roy <yeupou@gnu.org>
 # xhtml.pl: this file is part of package_db_view
 #
 #   XHTML (and HTML) rendering
@@ -14,7 +14,7 @@
 #  take a look at http://savannah.nongnu.org/projects/pdbv
 #  send comments at <pdbv-dev@nongnu.org>
 #
-#  $Id: xhtml.pl,v 1.26 2004/03/28 15:54:54 yeupou Exp $
+#  $Id: xhtml.pl,v 1.30 2005/02/23 10:42:20 yeupou Exp $
 
 print "The purpose of this file is not being executed alone";
 exit;
@@ -119,6 +119,7 @@ sub PdbvXhtmlPrintListFrame {
 		print $handle "<a name=\"".$crit."\" href=\"#".$crit."\" class=\"bold\">".$crit."</a>".$tag_line_break;
 	    }
 	    my $pkg_number = 0;
+	    
 	    foreach my $pack (PdbvPackagesSorted()) {
 		if ($$criterion{$pack} eq $crit) {
 		    $pkg_number++;
@@ -126,9 +127,14 @@ sub PdbvXhtmlPrintListFrame {
 		}
 	    }
 	    print $handle $tag_line_break;
+
+	    # Store the sum of packages for each section
+	    $section_packages_sum{$crit} = $pkg_number if $criterion eq "package_section";
+	    $usage_packages_sum{$crit} = $pkg_number if $criterion eq "package_popularity";
 	}
 	
 	
+	
     }
     PdbvXhtmlPrintFooter($handle);
 }
@@ -236,22 +242,69 @@ sub PdbvXhtmlPrintInfoFrame {
     my $handle = STDOUT;
     $handle = $_[0] if $_[0];
 
-    PdbvXhtmlPrintHeader($handle, gettext("Infos"));
-    PdbvSysinfoPrintDistro($handle);
-    print $handle "<br />";
-    PdbvSysinfoPrintUnameKernel($handle);
-    print $handle "<br />";
-    PdbvSysinfoPrintUnameCpu($handle);
-    print $handle "<br />";
-    PdbvSysinfoPrintFree($handle);
-    print $handle "<br /><br />";
+    PdbvXhtmlPrintHeader($handle, gettext("Information"));
+    
+    print $handle "<p>";
     print $handle sprintf(gettext("This is the output of %s version %s, running on %s. "), "<a href=\"$surl\">$sname</a>", $sver, hostname());
     print $handle sprintf(gettext("It was generated in %s."), PdbvExecutionTime());
-    print $handle "<p>";
-    print $handle gettext("Pdbv is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.");
-    print $handle "</p><p>";
-    print $handle gettext("This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.")."<a href=\"http://www.gnu.org/licenses/gpl.html\">".gettext("See the GNU General Public License for more details.")."</a>";
     print $handle "</p>";
+    
+
+    print $handle "<h2>".gettext("Packages Database Information")."</h2>";
+    print $handle "<p>";
+    print $handle sprintf(gettext("There are %s packages in the database."), scalar(@package_list));
+    if ($package_installedsize_sum) {
+	print $handle " ".sprintf(gettext("Installed packages take around %s of disk space."), PdbvXhtmlMakeSize($package_installedsize_sum));
+    }
+    print $handle "</p>";
+    # For each section, show the number of packages found (active only if
+    # section listing was made or if there's cached information about that
+    my $ret;
+    while(my($section,$sum) = each(%section_packages_sum)) {
+	$ret .= " <a href=\"list_bygroup.html#$section\" target=\"list\">".sprintf(gettext("%s in %s"), $sum, $section)."</a>," if $section;
+    }
+    if ($ret) {
+	chop($ret);
+	print $handle "<p>".gettext("Packages were found in the following sections:")." $ret.</p>";
+	open(FOUNDINSECTIONCACHE, "> $working_dir/foundinsections");
+	print FOUNDINSECTIONCACHE "<p>".gettext("Packages were found in the following sections:")." $ret.</p>";
+
+    } elsif (-e $working_dir."/foundinsections") {
+	open(FOUNDINSECTIONCACHE, "< $working_dir/foundinsections");
+	while (<FOUNDINSECTIONCACHE>) {
+	    print $handle $_;
+	}
+	close(FOUNDINSECTIONCACHE);
+    }
+
+    # For each usage , show the number of packages found (active only if
+    # usage listing was made or if there's cached information about that
+    $ret = "";
+    if ($package_popularity_activated) {
+	while(my($usage,$sum) = each(%usage_packages_sum)) {
+	    $ret .= " <a href=\"list_byusage.html#$usage\" target=\"list\">$sum $usage</a>," if $usage;
+	}
+	if ($ret) {
+	    chop($ret);
+	    print $handle "<p>".gettext("Packages usage appears as following:")." $ret.</p>";
+	    open(FOUNDINUSAGECACHE, "> $working_dir/foundinusage");
+	    print FOUNDINUSAGECACHE "<p>".gettext("Packages usage appears as following:")." $ret.</p>";
+	    
+	} elsif (-e $working_dir."/foundinusage") {
+	    open(FOUNDINUSAGECACHE, "< $working_dir/foundinusage");
+	    while (<FOUNDINUSAGECACHE>) {
+		print $handle $_;
+	    }
+	    close(FOUNDINUSAGECACHE);
+	}	
+    }
+
+    print $handle "<h2>".gettext("System Information")."</h2>";
+    print $handle "<p>";
+    print $handle sprintf(gettext("The system appears to be running %s along with the %s."), PdbvSysinfoGetDistro(), PdbvSysinfoGetUnameKernel())."</p><p>";
+    print $handle sprintf(gettext("It is %s with %s."), PdbvSysinfoGetUnameCpu(), PdbvSysinfoGetFree());
+    print $handle "</p>";
+
     PdbvXhtmlPrintFooter($handle);
 }
 
@@ -411,14 +464,9 @@ sub PdbvXhtmlMakeDate {
     return $year.", ".$month;
 }
 
-
-sub PdbvXhtmlPrintSizeBox { 
-    # It was planed to make an exact graphical representation, but
-    # $percent almost never reach one.
-    my $handle = STDOUT;
-    $handle = $_[0] if $_[0];
-
-    my $size = $_[1];
+sub PdbvXhtmlMakeSize {
+    my $size = $_[0];
+    
     if ($size >= 1048576) {
 	$size = (($size / 1048576 * 100) / 100);
 	$size = sprintf("%2.f", $size)." ".gettext("GB");
@@ -428,7 +476,18 @@ sub PdbvXhtmlPrintSizeBox {
     } else {
 	$size = sprintf("%2.f", $size)." ".gettext("kB");
     }
+    
+    return $size;
+}
 
+
+sub PdbvXhtmlPrintSizeBox { 
+    # It was planed to make an exact graphical representation, but
+    # $percent almost never reach one.
+    my $handle = STDOUT;
+    $handle = $_[0] if $_[0];
+
+    my $size = PdbvXhtmlMakeSize($_[1]);
     my $percent = (($_[1] / $package_installedsize_sum) * 100);
     my $percent_exagerated = sprintf("%2.f\%", ($percent * 100));
     
@@ -446,11 +505,11 @@ sub PdbvXhtmlPrintPopularityBox {
     my $handle = STDOUT;
     $handle = $_[0] if $_[0];
 
-    if ($_[1] eq 'recently installed') {
+    if ($_[1] eq gettext("recently installed")) {
 	print $handle " ".gettext("This package has been installed or updated recently, we do not have meaningful data.");
-    } elsif ($_[1] eq 'no executable files') {
+    } elsif ($_[1] eq gettext("with no executable files")) {
 	print $handle " ".gettext("No executable program has been found in this package, we cannot find meaningful data.");
-    } elsif ($_[1] eq 'unused') {
+    } elsif ($_[1] eq gettext("unused")) {
 	print $handle $tag_line_break."<table nowrap width=\"100%\" class=\"percentboxused\"><tr><td>".gettext("This package has not been used since more than a month.")."</td></tr></table>";
     } else {
 	print $handle $tag_line_break."<table nowrap width=\"100%\" class=\"percentbox\"><tr><td>".gettext("This package seems to be frequently used.")."</td></tr></table>";
